@@ -1,12 +1,12 @@
-      SUBROUTINE MWRAP(N,WT,NMATCH)
-      
-      INTEGER BASIS(5001),MEM(5001),KA(5001)
-      INTEGER KB(5001),ZFW,NMATCH(5001),CC(26000000)
-      INTEGER SM(5001),TMA(5001),TMB(5001),INDEX(5001)
-      INTEGER NBL(26000000), WT(26000000)
+      SUBROUTINE MWRAP(N,WT,NMATCH,PRCN)
+
+      INTEGER BASIS(N),MEM(N),KA(N),PRCN
+      INTEGER KB(N),ZFW,NMATCH(N),CC(N*(N-1))
+      INTEGER SM(N),TMA(N),TMB(N),INDEX(N+1)
+      INTEGER NBL(N*(N-1)), WT(N*N)
       INTEGER M1,NN,X,Y,N,M,I
-      DOUBLE PRECISION  Y1(5001),Y2(5001),DMINUS(5001),DPLUS(5001)
-  
+      DOUBLE PRECISION  Y1(N),Y2(N),DMINUS(N),DPLUS(N)
+
       M=N*(N-1)/2
       M1=2*M
       NN=0
@@ -19,14 +19,16 @@
  35   CONTINUE
       INDEX(X)=(X-1)*(N-1)+1
  25   CONTINUE
-      INDEX(N+1)=N*(N-1)+1      
-
+      INDEX(N+1)=N*(N-1)+1
       EPS=10.**(-38)
+      IF(PRCN.lt.6) THEN
       SUP=40000000
+      ELSE
+      SUP=4*10.**(PRCN+1)
+      ENDIF
       CALL SAP(N,M,CC,NBL,INDEX,ZFW,
      *NMATCH,BASIS,MEM,KA,KB,SM,
      *TMA,TMB,Y1,Y2,DPLUS,DMINUS,
      *SUP,EPS)
 
-
       END SUBROUTINE
